@@ -235,7 +235,8 @@ class PluginUploader:
             setup_script.write('grant usage on function PLUGIN.OMNATA_PLUGIN_INFO() to application role OMNATA_MANAGEMENT;\n')
             templates_path = os.path.join(Path(__file__).parent,'jinja_templates')
             environment = Environment(loader=FileSystemLoader(templates_path))
-            for proc_template in ['API_LIMITS','APPLY','CONFIGURATION_FORM','CONNECTION_TEST','CONNECTION_FORM']:
+            # These are all the procs which underneath, need to talk to the plugin code and therefore need all the imports available
+            for proc_template in ['API_LIMITS','APPLY','CONFIGURATION_FORM','CONNECTION_TEST','CONNECTION_FORM','CREATE_BILLING_EVENTS','NETWORK_ADDRESSES']:
                 template = environment.get_template(f'{proc_template}.sql.jinja')
                 content = template.render({
                     "plugin_fqn": plugin_fqn,
@@ -244,6 +245,7 @@ class PluginUploader:
                     "plugin_class_module": PLUGIN_MODULE,
                 })
                 setup_script.write(f"{content}\n")
+            # These are all the standard procs which do administrative tasks without talking to the plugin code
             for proc_template in ['CONFIGURE_APIS','UPDATE_API_CONFIGURATION','TEST_CALLBACK','CREATE_SECRET_OBJECT','CREATE_NETWORK_RULE_OBJECT']:
                 template = environment.get_template(f'{proc_template}.sql.jinja')
                 content = template.render({
